==> haskell-pcre-light-0.4.1.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-light.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-light
version:              0.4.1.0
visibility:           public
id:                   pcre-light-0.4.1.0-EZUXXUYzr3nDTU4wefFVqg
key:                  pcre-light-0.4.1.0-EZUXXUYzr3nDTU4wefFVqg
license:              BSD-3-Clause
copyright:            (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer:           Daniel Díaz <dhelta.diaz@gmail.com>
author:               Don Stewart
homepage:             https://github.com/Daniel-Diaz/pcre-light
synopsis:
    Portable regex library for Perl 5 compatible regular expressions

description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions

    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.

    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux) or @brew install pcre@ (MacOS).

category:             Text
abi:                  eeb03d629b19e3ef46b7e0a6092df269
exposed:              True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Base
    Text.Regex.PCRE.Light.Char8

import-dirs:          /usr/lib/ghc-8.10.1/site-local/pcre-light-0.4.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pcre-light-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/pcre-light-0.4.1.0
hs-libraries:         HSpcre-light-0.4.1.0-EZUXXUYzr3nDTU4wefFVqg
extra-libraries:      pcre
depends:              base-4.14.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html:         /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-light-0.4.1.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-light.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-light
version:              0.4.1.0
visibility:           public
id:                   pcre-light-0.4.1.0-6fqh8xZRCwm6ZmjfMT7gnt
key:                  pcre-light-0.4.1.0-6fqh8xZRCwm6ZmjfMT7gnt
license:              BSD-3-Clause
copyright:            (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer:           Daniel Díaz <dhelta.diaz@gmail.com>
author:               Don Stewart
homepage:             https://github.com/Daniel-Diaz/pcre-light
synopsis:
    Portable regex library for Perl 5 compatible regular expressions

description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions

    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.

    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux) or @brew install pcre@ (MacOS).

category:             Text
abi:                  4443eae9d5d50f674916ada1fa177678
exposed:              True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Base
    Text.Regex.PCRE.Light.Char8

import-dirs:          /usr/lib/ghc-8.10.1/site-local/pcre-light-0.4.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pcre-light-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/pcre-light-0.4.1.0
hs-libraries:         HSpcre-light-0.4.1.0-6fqh8xZRCwm6ZmjfMT7gnt
extra-libraries:      pcre
depends:              base-4.14.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html:         /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
